function [acceptance]=acceptreject(oldenergy, newenergy, beta)
% ACCEPTREJECT Determines acceptance of a monte carlo step
%   [ACCEPTANCE]=ACCEPTREJECT(OLDENERGY,NEWENERGY,BETA) returns either
%   'accept' or 'reject'.  If NEWENERGY is less than OLDENERGY, 'accept' is
%   passed since it is energetically favorable to go to the lower energy.
%   If NEWENERGY is not lower than OLDENERGY, a random number between 0 and
%   1 is generated.  If EXP(-BETA*(NEWENERGY-OLDENERGY)) is greater than this
%   random number, 'accept' is returned. Otherwise, 'reject' is returned.
%
%   %Example:
%
%   >>nrg1=-3.4; nrg2=-3.7; beta=1.4;
%   >>ac=acceptrejct(nrg1,nrg2,beta)
%      
%    ac='accept'
%
% See also ALTERSYS, MC

%set energy difference 
delta= beta *(newenergy-oldenergy);

%if energy decreases, accept step
if(delta<=0.0)
    acceptance='accept';
    
%if energy goes up by and acceptable amount as determined by a random
%number, accept step
elseif(exp(-delta)>rand(1))
    acceptance='accept';

%doesn't meet criterion, reject step
else
    acceptance='reject';
end