function [sysout]=altersys(sysin,run,alter)
% ALTERSYS Changes some aspect of a system
%   [SYSOUT]=ALTERSYS(SYSIN,RUN,ALTER) is an altered system.  This alteration may
%   be moving an atom or group of atoms, switching atom kinds, spin flips,
%   or whatever relevant system change the user wishes to study.  This
%   function is useful when performing a monte carlo run.  At each step,
%   the system can be altered such that the energy minimum can be found.
%   ALTER gives the atoms to change.  RUN gives information on what to
%   alter.
%   
%   %Example:
%
%   >>sys=makesys;
%
%   >>newsys=altersys(sys);
%
% See also ACCEPTREJECT, MC

persistent rndlst;
persistent rndcnt;

if (isempty(rndlst) | (rndcnt>length(alter)*run.N))
    rndlst=randint(1,length(alter)*run.N,[1,sysin.nkind-1]); % Only works if nalter is fixed for a given run.
    rndcnt=1;
end

sysout=sysin;
switch run.alter
    case 'ChangeKind'
    %Changes the kind of a atoms.  For Grand Canonical MC.
        %Change kinds to new values for atoms in alter.
        nalter=length(alter);
        %shift=randint(1,nalter,[1,sysin.nkind-1]);
        shift=rndlst(rndcnt:rndcnt+nalter-1);
        rndcnt=rndcnt+nalter;
        newkind=mod((sysin.kind(alter(:))-1+shift'),sysin.nkind)+1;
        sysout.kind(alter(:))=newkind(:);
        %check for self consistency
        %check(sys);
     case 'SwapKind'
    %Swaps pairs of atoms.  For Canonical MC.
        %Swap atoms in alter.  Work in pairs.
        nalter=length(alter);
        if (mod(nalter,2)==1)
          error('ERROR ALTERSYS: you must set number of altered atoms to an even number.');
        end
        for i=1:2:length(alter)
            sysout=SwapAtoms(sysout,alter(i),alter(i+1));
        end
    otherwise 
        error('ERROR ALTERSYS: No such alteration (run.alter) found');
end