function [shifts,acorr,varmean]=autocorr(v,numeval)
% [SHIFTS, ACORR, VAR]=AUTOCORR(V) returns information on the
% autocorrelation of v. The autocorrelation is defined by
% acorr(l)=(1/(L-l))Sum_t=1:L-l[v(t)*v(t+l)] - vmean^2 where L=length(v).
% The shifts gives the points l on which the autocorr is evaluated. This is
% supplied by the user or default to min(500,L). varmean is the variance in
% the mean of v as calculated from the autocorrelation.
% Todo:  Check normalizations.

% Check for number of points to evaluate

if (nargin==1)
    numeval=L;
end

vmean=mean(v);
[L,n]=size(v);
% Number of points at which to evaluate autocorrelation function.
% Max value would be L.
evalinterval=max(1,floor((L-1)/numeval));

% Loop over colums tand treat each separately
for j=1:n
    norm(j)=(v(:,j)'*v(:,j)/L-vmean(j)^2);
end
for j=1:n
    if (norm(j)<1e-12) % No variance in the data
        acorr=zeros(size(v));
    else
        cnt=0;
        for l=1:evalinterval:L-1
            cnt=cnt+1;
            acorr(cnt,j)=(v(1:(L-l),j)'*v((l+1):L,j)/(L-l)-vmean(j)^2)/norm(j);
            shifts(cnt)=l;
        end
    end
    % Calculated the variance vs. # steps
%     den=1:cnt;
%     den=den+1;
%     sumacorr(:,j)=cumsum(acorr(:,j));
%     varmean(:,j)=(sumacorr(:,j)+1)*norm(j);
%     varmean(:,j)=varmean(:,j)./den(:);
    varmean=zeros(size(acorr)); % Code up calculation of this.
end
