function check(system)
% CHECK Determines if system is self consistent.
%   CHECK(SYSTEM) will return an error if the length of SYSTEM.POS,
%   SYSTEM.NAME or SYSTEM.KIND are not of length SYSTEM.NUMATMS.  The user
%   may alter this check to make sure that other aspects of the system are
%   self consistent.
%
%   %Example:
%
%   >>sys=makesys;
%   >>check(sys);
%
%   %Example2:
%
%   >>sys=makesys;
%   >>sys.pos(sys.numatms+1,:)=[2.3 3.1 1.5];
%   >>check(sys)
%       ??? Error using ==> check
%       Number of atoms does not match length of position
%
% See also MAKESYS, LOADSYS, SAVESYS, SETPOS 

%intialize variables
numatms=system.numatms;
pos=size(system.pos);
name=length(system.name);
kind=length(system.kind);

%does the number of atoms match the length of the atom positions matrix?
if numatms~=pos(1)
    error('Subroutine check: Number of atoms does not match length of position')
end

%does the number of atoms match the length of the atom name matrix?
if numatms~=name
    error('Subroutine check: Number of atoms does not match length of name')
end

%does the number of atoms match the length of the atom kind matrix?
if numatms~=kind
    error('Subroutine check: Number of atoms does not match length of kind')
end

%does the potential match the potential parameters

