%exampleMC.m
%SCRIPT FILE
%exampleMC -This is the main program script example that runs the monte
%carlo code over varying beta values of an fcc cyrstal with 2 atom kinds.
%The type of system alteration is a kind swap between the 2 kinds. 
%This file is included to give an idea
%of how the toolbox functions may be used.

%clear workspace variables
clear
%create system based on fcc2
sys.numatms=4;
sys.pos=[0 0 0; .5 .5 0; .5 0 .5; 0 .5 .5];
sys.name=[1:4]';
sys.kind=[1 2 2 2]';
sys.dim=3;
sys.lat='fcc2';
sys.latvec=[1 0 0; 0 1 0; 0 0 1];
sys.pbc=[1 1 1];
sys.rcut=0.8;

%potential variable
sys.potent='Ising';
sys.J=0.0;
sys.eps=[-sys.J sys.J; sys.J -sys.J];
sys.mu=[0.0 0.0];

%super cell vectors
vec=[3 0 0; 0 3 0; 0 0 3];

%make sys a supercell
sys=makesupercell(sys,vec);

%set how many equilibration steps are to done
run.equilibN=4;
%set how many monte carlo steps are to be done (total steps = equilibN + N )
run.N=8;
%set how the system is altered at each step
run.alter='binary kind swap';

%create array of beta values to scan over
j=[ 0.03, 0.02, 0.01];


%initialize concentration average values
c1avg=[];
c2avg=[];
c1=[];
c2=[];

%step over beta values stored in j
for i=1:length(j)

    %print which run
    disp('Temp Step:')
    disp(i)

    %set beta for this run
    run.beta=j(i)
    %do the monte carlo run for this beta
    [monte monteRun]=mc(sys,run);
    
    %save run data
    runHist(i)=monteRun;
    sysHist(i)=monte;

    %append averaged concentrations to array
    c1(i,:)=monteRun.concentration1;
    c2(i,:)=monteRun.concentration2;
    c1avg(i)=sum(monteRun.concentration1)/monteRun.N
    c2avg(i)=sum(monteRun.concentration2)/monteRun.N
  end

%save workspace as "example.mat"
save example

% %plot concentrations of kind 1 and kind 2 atoms
% plot(j,[c1avg; c2avg])
