function d = findDeltaR(system)
% findDeltR Computes Euclidean distance matrix for SYSTEM.POS
%   [D]=findDeltaR(SYSTEM) is a SYSTEM.NUMATM x SYSTEM.NUMATM matrix that
%   contains the distances between all atoms in the system.
%
%   %Example:
%   >>sys=makesys;
%   >>distancMatrix=findDeltaR(sys);
%   
%   The value of distanceMatrix(3,6) = distanceMatrix(6,3) and is the
%   Euclidean distance between the atom whose position is given third in
%   SYSTEM.POS and the atom whose position is given sixth in SYSTEM.POS
%
%   Orignial Author   : Roland Bunschoten
%                       University of Amsterdam
%                       Intelligent Autonomous Systems (IAS) group
%                       Kruislaan 403  1098 SJ Amsterdam
%                       tel.(+31)20-5257524
%                       bunschot@wins.uva.nl
%
%   Modified: Ted Holby
%
%   Copyright notice: You are free to modify, extend and distribute 
%   this code granted that the author of the original code is 
%   mentioned as the original author of the code.
%
% See also FINDNGBRS

if (nargin ~= 1)
   error('Not enough input arguments');
end

%initialize
a=sys.pos';
b=sys.pos';

%create matrix
aa=sum(a.*a,1); bb=sum(b.*b,1); ab=a'*b; 
d = sqrt(abs(repmat(aa',[1 size(bb,2)]) + repmat(bb,[size(aa,2) 1]) - 2*ab));