function [dE]=findDeltaSysEnergy(newsys,oldsys,alter)
% findDeltaSysEnergy Calculates the change in interaction energy between
% atoms in a system.
%   [DE]=findSysEnergy(NEWSYS,OLDSYS,ALTER) is the change in energy in
%   going from system OLDSYS to system NEWSYS, where atoms alter have been changed.
%   The energy calculation is based on SYS.POTENT (which potential is being
%   used).
%
% See also findSysEnergy, mc

persistent ngbrs; % Does this last for totally different sys???

%initialize
oldE=0;
newE=0;
% Remove any duplicate altered atoms
alter=unique(alter);
nchatoms=length(alter);

%which potential is being used?
switch  oldsys.potent
    case 'Ising'
        % The neighbor topology is assumed not to change so these are foudn
        % just once for all atoms and kept persistent
        if isempty(ngbrs)
            ngbrs=findngbrs(oldsys,[1:oldsys.numatms]);
        end
        % Set chgflg array to 0 for no change, 1 for change, for every
        % atom.
        chgflg=zeros(1,oldsys.numatms);
        chgflg(alter)=1;
        % Get energies
        %loop over all altered atoms and their neighbors
        for i=alter
            old_inrg=oldsys.VNN(oldsys.kind(i),oldsys.kind(ngbrs(i).id));
            new_inrg=newsys.VNN(newsys.kind(i),newsys.kind(ngbrs(i).id));
            % For each neighbor of atom i divide E by 2 if its id is in
            % alter - this corrects for double counting bonds between atoms
            % that were both changed.
            rescale=chgflg(ngbrs(i).id(:)); % 0 and 1's.
            rescale=rescale+1; % 1's and 2's.
            rescale=1./rescale; % 1's and 1/2's.
            old_inrg=old_inrg.*rescale; % Divides all double counted bonds by 2.
            new_inrg=new_inrg.*rescale; % Divides all double counted bonds by 2.
            %             for j=1:ngbrs(i).numngbrs
            %                 if (chgflg(ngbrs(i).id(j))==1)
            %                     inrg(j)=inrg(j)/2;
            %                 end
            %             end
            old_ithEnergy=sum(old_inrg);
            new_ithEnergy=sum(new_inrg);
            oldE=oldE+old_ithEnergy;
            newE=newE+new_ithEnergy;
        end
        dE=(newE-oldE);
    otherwise
        error('No such potential case (sys.potent)in findsysENRG.m');
end
