function [sysenrg]=findSysEnergy(sys)
% findSysEnergy Calculates the interaction energy between atoms in a system
%   [SYSENRG]=findSysEnergy(SYS) is the energy of a system SYS based on
%   SYS.POTENT (which potential is being used) and the system's
%   configuration.  
%
%   %Example:
%   >>sys=makesys;
%   >>sys.potent
%    ans =
% 
%    Ising
%
%   >>systemenergy=findSysEnergy(sys)
%
%    systemenergy =
% 
%      -432
%
% See also FINDNGBRS, WHICHCELL

%initialize
sysenrg=0.0;

%which potential is being used?
switch  sys.potent
    case 'Ising'
        ngbrs=findngbrs(sys,1:sys.numatms);
        %loop over all atoms
        for i=1:sys.numatms
            inrg=sys.VNN(ngbrs(i).kind,ngbrs(i).ngbrkind);
            ithEnergy=sum(inrg);
            sysenrg=sysenrg+ithEnergy;
        end
        %divide by 2 to account for double counting
        sysenrg=sysenrg/2.0;
    otherwise
        error('No such potential case (sys.potent)in findsysENRG.m');
end
