function [system]=makesys(varargin)
% MAKESYS creates a system structure based on input arguments and default
% values stored in sys_default.m
%   [SYSTEM]=MAKESYS(VARARGIN) is a system structure.  If no arguments are
%   passed, then the variables stored on default.m will be used.  Other
%   files can be used to make a system using the 'mfilein' and 'matfilein'
%   input flags.  To input new variables (not stored in loading file), the
%   the user must pass two arguments, the first being the name of the new
%   structure field in single quotes ('newfieldname') and the value of the
%   new structure field.  
%
%   %Example 1:
%
%   >>mySystem=makesys;
%   This example creates a system struct based on the values of variables in
%   sys_default.m
%
%   %Example 2:
%   >>mySystem=makesys('mfilein','mySysFile')
%   This example creates a sys struct based on the values of variables in
%   mySysFile.m
%
%   %Example3:
%   spinVal=[1 -1 1 1 -1];
%   >>mySystem=makesys('spin',spinVal)
%   This example creates a system structure based on the values of
%   variables in default.m with the addition of mySystem.spin=[1 -1 1 1 -1]
%
% See also SAVESYS, LOADSYS, PRINTSYS, SETPOS

%leng tells how many variables were passed into the initsys function 
leng=length(varargin);

%The case that no arguments are passed... use default
if(leng == 0)
    sys.init='loadDefault';
    file='default';
    run(file)
    system=sys;
    check(system);
    return
end

%switch/case variable
init=varargin{1};

switch init
    
    case 'mfilein'
    %Using an mfile input
       sys.init='loadmfile';
       file=varargin{2};
       run(file)
       for(h=3:2:leng)    
            sys=setfield(sys, varargin{h}, varargin{h+1});
       end
       system=sys;
       check(system);
       return
        
    case 'matfilein'
    %using a matfile input
       sys=loadsys(varargin{2});
       for(j=3:2:leng)    
            sys=setfield(sys, varargin{j}, varargin{j+1});
       end
       system=sys;
       check(system);
       return

    otherwise
    %using default with modified parameters
       sys.init='loadDefaultPlus';
       file='default';
       run(file)
       for(i=1:2:leng)    
            sys=setfield(sys, varargin{i}, varargin{i+1});
       end
       sys=setpos(sys);
       system=sys;
       check(system);
       return
end
