% mcrun.m
% MCRUN.M is the control code for the UIUC Summer School lab, 6/22/05.

% MC runs
clear all;
% Plot colors
colors=['b','g','r','c','m','y'];
ncolor=length(colors);
% Set random number generator
rand('state',1) % Sets the random number generator to same state each time.
rand('state',sum(100*clock)) % Sets the random number generator to different state each time
disp(['First random number: ' num2str(rand)]);
% Get system
sys=makesys('mfilein','InSys3_SC');

% Exercises list - ALTER
exerlist=[...
    1 ...% Exercise 1 - ALTER
    0 ...% Exercise 2 - ALTER
    0 ...% Exercise 3 - ALTER
    0    % Exercise 4 - ALTER
    ];
exer=0;

% General defaults
sc=3; % Supercell multiple (creates 8xsc^3 atoms) - ALTER
sys=makesupercell(sys,sc*sys.latvec); % System size
run.mu(1)=0.0;run.mu(2)=0.0; % Chemical potential
run.alter='ChangeKind';

% Change initial ordering - ALTER
sys.kind=sys.kind(randperm(sys.numatms)); % Randomly permutes input kind - ALTER
sys.kind=2*ones(size(sys.kind)); % All twos - ALTER
sys.kind=ones(size(sys.kind)); % All ones - ALTER
sys.kind=randint(sys.numatms,1)+1; % Gives random 1's and 2's. - ALTER

% Exercise 1
exer=exer+1;
if(exerlist(exer))
    disp(['Exercise ' num2str(exer)]);
    % Set run params
    run.equilibN=1000;  % ALTER
    run.N=10*10^3; % ALTER
    Ti=8;Tf=8;nT=1; % ALTER
    Tvec=linspace(Ti,Tf,nT);
    % Create figure
    fh=figure;
    hold on;
    title('Energy vs. MC Step - Real time');
    % Loop over temp
    Tcnt=0;
    for T=Tvec
        disp(['Temp: ' num2str(T)]);
        Tcnt=Tcnt+1;
        run.beta=1/T;
        % Run MC
        [newsys run]=mc(sys,run);
        % Collect data
        E_all(Tcnt,:)=run.E_all;
        pacc(Tcnt)=run.nacc/run.N;
        C_all(Tcnt,:)=run.N_all(:,2)'/newsys.numatms;
        Emean(Tcnt)=run.E_mean;
        Cmean(Tcnt)=run.N_mean(2)/sys.numatms;
        % Plot concentration real time
        plot([1:run.N+1]',E_all(Tcnt,:)',[colors(mod(Tcnt-1,ncolor)+1)]);
        legtxt=num2str(Tvec');
        legend(legtxt);
        refreshdata(fh);
        drawnow;
    end
    hold off;
    % Plot energy
    figure;
    hold on;
    plot(C_all(:,:)');
    legtxt=num2str(Tvec');
    legend(legtxt);
    title('Conc vs. MC Step');
    hold off;
    % Plot acceptance
    figure;
    hold on;
    plot(Tvec,pacc,'o');
    title('Acceptance fraction vs. Temp');
    hold off;
    % Plot conc autocorrelation
    figure;
    hold on;
    [shifts,Cacorr,varcmean]=autocorr(C_all(:,run.equilibN+1:end)',500);
    plot(shifts(1:floor(end/2)),Cacorr(1:floor(end/2),:));
    legtxt=num2str(Tvec');
    legend(legtxt);
    title('Conc Autocorr vs. Delta MC Step');
    hold off;
    % Plot ener autocorrelation
    figure;
    hold on;
    [shifts,Eacorr,varemean]=autocorr(E_all(:,run.equilibN+1:end)',500);
    plot(shifts(1:floor(end/2)),Eacorr(1:floor(end/2),:));
    legtxt=num2str(Tvec');
    legend(legtxt);
    title('Energy Autocorr vs. Delta MC Step');
    hold off;
    %     % Plot std dev in mean of energy
    %     figure;
    %     hold on;
    %     plot(shifts(1:floor(end/2)),sqrt(varemean(1:floor(end/2),:)));
    %     legtxt=num2str(Tvec');
    %     legend(legtxt);
    %      title('Std deviation in E mean vs. Delta MC Step');
    %     hold off;
end

% Exercise 2
exer=exer+1;
if(exerlist(exer))
    disp(['Exercise ' num2str(exer)]);
    % Set run params
    run.equilibN=5*10^2;  % ALTER
    run.N=1*10^3; % ALTER
    Ti=5.5;Tf=3.5;nT=11; % ALTER
    Tvec=linspace(Ti,Tf,nT);
    newsys=sys;
    % Create figure
    fh=figure;
    hold on;
    title('Conc vs. MC Step - Real time');
    % Loop over temp
    Tcnt=0;
    for T=Tvec
        disp(['Temp: ' num2str(T)]);
        Tcnt=Tcnt+1;
        run.beta=1/T;
        [newsys run]=mc(newsys,run);
        Eavg(Tcnt)=run.E_mean;
        Cavg(Tcnt)=run.N_mean(2)/newsys.numatms;
        Chi(Tcnt)=run.N_sd(2)/newsys.numatms;
        plot(T,Cavg(Tcnt),'o')
        refreshdata(fh);
        drawnow;
    end
    hold off;
    figure;
    hold on;
    plot(Tvec',[Eavg']);
    title('Energy vs. Temp');
    hold off;
    figure;
    hold on;
    plot(Tvec',[Chi']);
    title('Susceptbility Chi (dC/dBmu) vs. Temp');
    hold off;
    fid=fopen('OUT_X_Ex2','w');
    for i=1:length(Tvec)
        fprintf(fid,'%f  %f\n',Tvec(i),Chi(i));
    end
end

% Exercise 3
exer=exer+1;
if(exerlist(exer))
    disp(['Exercise ' num2str(exer)]);
    % Set run params
    run.equilibN=5*10^3;  % ALTER
    run.N=20*10^3; % ALTER
    Ti=3.5;Tf=5.5;nT=3; % ALTER
    MUi=-0.5;MUf=0.1;nMU=2; % ALTER
    newsys=sys;
    Tvec=linspace(Ti,Tf,nT);
    MUvec=linspace(MUi,MUf,nMU);
    newsys=sys;
    % Create figure
    figh1=figure;
    figh2=figure;
    figure(figh1);
    hold on;
    title('Conc vs. Chem Potential - Real time');
    figure(figh2);
    hold on;
    title('Semi-Grand Pot vs. Chem Pot - Real time');
    % Loop over temp
    Tcnt=0;
    for T=Tvec
        disp(['Temp: ' num2str(T)]);
        Tcnt=Tcnt+1;
        run.beta=1/T;
        MUcnt=0;
        % Increment
        newsys.kind=1*ones(size(newsys.kind)); % All ones - ALTER
        for MU=MUvec
            disp(['MU: ' num2str(MU)]);
            MUcnt=MUcnt+1;
            run.mu(2)=MU;
            [newsys run]=mc(newsys,run);
            Eavg_inc(Tcnt,MUcnt)=run.E_mean;
            Cavg_inc(Tcnt,MUcnt)=run.N_mean(2)/newsys.numatms;
            % Plot concentration real time
            figure(figh1);
            lh1_inc(Tcnt)=plot(MU,Cavg_inc(Tcnt,MUcnt),[colors(mod(Tcnt-1,ncolor)+1) 'o']);
            refreshdata(figh1);
            drawnow;
        end
        % Decrement
        MUcnt=0;
        newsys.kind=2*ones(size(newsys.kind)); % All twos - ALTER
        for MU=-MUvec
            disp(['MU: ' num2str(MU)]);
            MUcnt=MUcnt+1;
            run.mu(2)=MU;
            [newsys run]=mc(newsys,run);
            Eavg_dec(Tcnt,MUcnt)=run.E_mean;
            Cavg_dec(Tcnt,MUcnt)=run.N_mean(2)/newsys.numatms;
            % Plot concentration real time
            figure(figh1);
            lh1_dec(Tcnt)=plot(MU,Cavg_dec(Tcnt,MUcnt),[colors(mod(Tcnt-1,ncolor)+1) '+']);
            refreshdata(figh1);
            drawnow;
        end
        legtxt=[num2str(Tvec(1:Tcnt)');num2str(Tvec(1:Tcnt)')];
        legend([lh1_inc,lh1_dec],[legtxt]);
        refreshdata(figh1);
        drawnow;
        % Thermodynamic integration
        phi0=-MUvec(1)*Cavg_inc(Tcnt,1);
        phi_inc(Tcnt,:)=thermint(phi0,Eavg_inc(Tcnt,:)',Cavg_inc(Tcnt,:)',run.beta,MUvec');
        phi0=MUvec(1)*Cavg_dec(Tcnt,1);
        phi_dec(Tcnt,:)=thermint(phi0,Eavg_dec(Tcnt,:)',Cavg_dec(Tcnt,:)',run.beta,-MUvec');
        figure(figh2);
        % Plot semi-grand potentials
        lh2_inc(Tcnt)=plot(MUvec,phi_inc(Tcnt,:),[colors(mod(Tcnt-1,ncolor)+1) 'o-']);
        lh2_dec(Tcnt)=plot(-MUvec,phi_dec(Tcnt,:),[colors(mod(Tcnt-1,ncolor)+1) '+-']);
        legend([lh2_inc,lh2_dec],[legtxt]);
        refreshdata(figh2);
        drawnow;
    end
    figure(figh1);
    hold off;
    figure(figh2);
    hold off;
end

% Exercise 4
exer=exer+1;
if(exerlist(exer))
    disp(['Exercise ' num2str(exer)]);
    % Set run params
    run.equilibN=30000;  % ALTER
    run.N=60*10^3; % ALTER
    Ti=0.1;Tf=0.1;nT=1; % ALTER
    MUi=-10;MUf=-10;nMU=4; % ALTER
    % Make ordering systems
    sys.VNN(1,1)=1;
    sys.VNN(1,2)=-1;
    sys.VNN(2,1)=-1;
    sys.VNN(2,2)=1;
    newsys=sys;
    Tvec=linspace(Ti,Tf,nT);
    newsys=sys;
    % Create figure
    figh1=figure;
    hold on;
    title('Conc vs. Chem Potential - Real time');
    % Loop over temp
    Tcnt=0;
    for T=Tvec
        disp(['Temp: ' num2str(T)]);
        Tcnt=Tcnt+1;
        run.beta=1/T;
        MUcnt=0;
        MUvec=linspace(MUi,MUf,nMU);
        % Increment
        for MU=MUvec
            disp(['MU: ' num2str(MU)]);
            MUcnt=MUcnt+1;
            run.mu(2)=MU;
            [newsys run]=mc(newsys,run);
            Eavg_inc(Tcnt,MUcnt)=run.E_mean;
            Cavg_inc(Tcnt,MUcnt)=run.N_mean(2)/newsys.numatms;
            % Plot concentration real time
            figure(figh1);
            lh1_inc(Tcnt)=plot(MU,Cavg_inc(Tcnt,MUcnt),[colors(mod(Tcnt-1,ncolor)+1) 'o']);
            refreshdata(figh1);
            drawnow;
        end
        % Decrement
        MUcnt=0;
        MUvec=linspace(MUf,MUi,nMU);
        for MU=MUvec
            disp(['MU: ' num2str(MU)]);
            MUcnt=MUcnt+1;
            run.mu(2)=MU;
            [newsys run]=mc(newsys,run);
            Eavg_dec(Tcnt,MUcnt)=run.E_mean;
            Cavg_dec(Tcnt,MUcnt)=run.N_mean(2)/newsys.numatms;
            % Plot concentration real time
            figure(figh1);
            lh1_dec(Tcnt)=plot(MU,Cavg_dec(Tcnt,MUcnt),[colors(mod(Tcnt-1,ncolor)+1) '+']);
            refreshdata(figh1);
            drawnow;
        end
        legtxt=[num2str(Tvec(1:Tcnt)');num2str(Tvec(1:Tcnt)')];
        legend([lh1_inc,lh1_dec],[legtxt]);
        refreshdata(figh1);
        drawnow;
    end
    figure(figh1);
    hold off;
end



