function posplot(system)
% POSPLOT Plots the positions of the atoms from SYSTEM.POS.
%   POSPLOT(SYSTEM) will create a plot figure with points at the positions
%   indicated by SYSTEM.POS.  Based on SYSTEM.KIND atoms
%   of different kinds will be plotted a different color.  To change the
%   size of the points, change the size variable below.  The 'filled'
%   option can also be passed to SCATTER3 to create filled in points.  
%
%   %Example:
%   >>sys=makesys;
%   >>posplot(sys)
%
% See also SCATTER, SCATTER3, PRINTSYS

%make sure system is self consitent
check(system);

%2D case
if(system.dim == 2)
    scatter(system.pos(:,1),system.pos(:,2))
end

%3D case
if(system.dim == 3)
    %color will make different atom kinds different colors
    color=system.kind;
    size=100;
    %Filled need not be called
    scatter3(system.pos(:,1),system.pos(:,2),system.pos(:,3),size,color,'filled')
end