function printngbrs(ngbrs,file)
% PRINTNGBRS Prints out a ngbrs structure to a file in Ascii format
%   PRINTNGBRS(NGBRS, FILE) will write out ngbr variables stored in NGBRS
%   to FILE.txt in Ascii readable format.  The file will contain atom
%   position, atom name, atom kind and number of neighbors for that atom.
%   The function will then print out neighbor information for that given
%   atom incuding ngbrpos (neighbor position), ngbrkind (neighbor kind),
%   ngbrname (neighbor name), and disp (displacement betwen atom and
%   neighbor).
%
%   %Example:
%   >>sys=makesys;
%   >>ngbrs=findngbrs(sys,1:sys.numatms);
%   >>printngbrs(ngbrs,'myNeighborFile')
%
% See also FINDNGBRS, PRINTSYS

%This function takes in a ngbr struct and prints out the field names and values
%of those fields into a file named file.txt where file is the value
%of file passed in.
%Example:
%>> printngbrs(myNgbrs, saveMyNgbrs)
% writes out the fieldnames/values of the struct myNgbrs into saveMyNgbrs.txt

%initialize
filename=[file '.txt'];
fid = fopen(filename,'w');
leng=length(ngbrs);

% List of field names in ngbrs(i)

%     pos       [1x3]
%     name      [1x1]
%     kind      [1x1]
%     ngbrpos   [numngbrs x 3]
%     numngbrs  [number of neighbors]
%     ngbrkind  [numngbrs x 1]
%     ngbrname  [numngbrs x 1]
%     disp      [numngbrs x 1]

%print out header
fprintf(fid,'%s\n','**********Displacements**********');
fprintf(fid,'%s\n','Format:');
fprintf(fid,'%s\n','Atom name   Atom position  Number of Neighbors');
fprintf(fid,'%s\n','Neighbor Name    Neighbor Position   Neighbor Distance Neighbor Cell');
fprintf(fid,'%s\n',' ');

for(i=1:leng)

    %which atom's neighbors (name, kind, position and number of neighbors)
    fprintf(fid,'%s : ','Atom');
    fprintf(fid,'%i',ngbrs(i).name);
    fprintf(fid,'%s','  ');

    fprintf(fid,'%s : ','Kind');
    fprintf(fid,'%i',ngbrs(i).kind);
    fprintf(fid,'%s','  ');
    
    fprintf(fid,'%s : ','Pos:');
    fprintf(fid,'%1.4f ',ngbrs(i).pos(1));
    fprintf(fid,'%s','  ');
    fprintf(fid,'%1.4f ',ngbrs(i).pos(2));
    fprintf(fid,'%s','  ');
    fprintf(fid,'%1.4f ',ngbrs(i).pos(3));
    fprintf(fid,'%s','  ');
    
    fprintf(fid,'%s : ','Number of Neighbors');
    fprintf(fid,'%i',ngbrs(i).numngbrs);
    fprintf(fid,'%s','  ');
    
    fprintf(fid,'%s\n',' ');

    for(j=1:(ngbrs(i).numngbrs))
        %write out info about neighbors for ith atom
        fprintf(fid,'%s','  ');
        fprintf(fid,'%i',ngbrs(i).ngbrname(j));
        fprintf(fid,'%s','  ');
        
        %position of this neighbor    
        fprintf(fid,'%s : ','Pos');
        fprintf(fid,'%1.4f ',ngbrs(i).ngbrpos(j,1));
        fprintf(fid,'%s','  ');
        fprintf(fid,'%1.4f ',ngbrs(i).ngbrpos(j,2));
        fprintf(fid,'%s','  ');
        fprintf(fid,'%1.4f ',ngbrs(i).ngbrpos(j,3));
        fprintf(fid,'%s','  ');
        
        %displacement between ith and this neighbor
        fprintf(fid,'%s : ','Dist');
        fprintf(fid,'%1.4f',ngbrs(i).disp(j));
        fprintf(fid,'%s','  ');

        
        %which cell...
        fprintf(fid,'%s : ','Cell');
        fprintf(fid,'%i', ngbrs(i).cell(j,1));
        fprintf(fid,'%s','  ');
        fprintf(fid,'%i', ngbrs(i).cell(j,2));
        fprintf(fid,'%s','  ');
        fprintf(fid,'%i', ngbrs(i).cell(j,3));
        fprintf(fid,'%s','  ');

        
        fprintf(fid,'%s\n',' ');

    end
    
    fprintf(fid,'%s\n',' ');

end
%close file
fclose(fid);