function printsys(sys)
% PRINTSYS Writes out the fieldnames and field values of an arbitrary
% structure (such as a system structure) into SYS.FILEOUT in Ascii format.
%   PRINTSYS(SYS) writes out the field names and values of the structure
%   SYS into SYS.FILEOUT.  This file is Ascii readable.
%
%   %Example:
%   >>sys=maksys;
%   >>sys.fileout
% 
%     ans =
% 
%     MySystem
%
%   >>printsys(sys)
%
% See also SAVESYS, LOADSYS, MAKESYS, POSPLOT

%name of file to write out to
filename=[sys.fileout '.txt'];

%open file
fid = fopen(filename,'w');
%find what fields are contained in sys
fields=fieldnames(sys);
%find how many fields are containd in sys
fieldLeng=length(fields);

%write out all field names and values
for(i=1:fieldLeng)
    currentfield=char(fields(i))
    currentfieldValue=getfield(sys,currentfield)
    fprintf(fid,'%s : \n',currentfield)
    if (ischar(currentfieldValue)==1)
        fprintf(fid,'%s\n',currentfieldValue)
    else
        fprintf(fid,'%f\n',currentfieldValue)
    end
end

%close file
fclose(fid)