function [sys]=setpos(system)
% SETPOS Sets relevant system variables such as position, name, and kind 
% based on SYSTEM.LAT (lattice type).  
%   [SYS]=SETPOS(SYSTEM) is a new system with variables set up to adhear to
%   a specific lattice type.  To add a new type of lattice, the user must
%   add a new lattice case below.
%
%   %Example:
%   >>sys.lat='random'
%   >>sys.latvec=[1 0 0; 0 1 0; 0 0 1];
%   >>sys.numatms=30;
%   >>sys=setpos(sys)
%
%   sys now has not only .lat, .latvec, .numatms but also a numatms x 3
%   position array, a numatms x 1 name array and a numatms x 1 kind array.
%
% See also MAKESYS

switch system.lat
    
    %Set up a random distribution
    case 'random'
        
        %initialize
        sys=system;
        
        %set random positions inside lattice parameters
        position=rand(system.numatms, system.dim);
                             
        sys.pos(:,:)=position*system.latvec';

        %set kinds
        sys.kind=ones(system.numatms,1);
        %set names
        sys.name=[1:system.numatms]';
        check(sys);
    otherwise
        error('No such lattice type (sys.lat) found in setpos.m')
 
  end