%default.m
%SCRIPT FILE
%This file contains the default values for a new system.  These values can
%be changed to suite the needs of the user or a new file can be read
%in when creating a new system using makesys.
%
%   %Example 1:
%   >>default
%
%   The above example creates a system named sys with values from default.
%
%   %Example 2:
%   >>mySystem=makesys;
%
%   The above example creates a system named 'mySystem' with values from
%   default.
%
%   %Example 3:
%   >>mySystem=makesys('mfilein','default)
%
%   The above example creates a system named 'mySystem' with values from
%   default.
%
%   Note:using makesys('mfilein','mySysfile'), it is possible to create 
%   systems from m-files, the default being the values stored in this 
%   m-file.
%
% See also MAKESYS

%system variables

%output file name
sys.fileout='MySystem';

%number of atoms (NOTE: setpos may reset this)
sys.numatms=100;

%set system dimensionality
sys.dim=3;

%set coordinate type, default is Cartesian ('Cart')
sys.coords='Cart';

%set beta=1/T
sys.beta=0;

%set system pressure
sys.press=0;

%set system lattice type
sys.lat='random';

%set lattice vectors for system
sys.latvec=[5 1 0; 1 6 0; 1 1 4];

%atom variables 

%set position, kind, and name
sys=setpos(sys);

%set potential type
sys.potent='Ising';

%inteaction energy matrix for 2 kinds of atoms
sys.eps(1,1)=-1;
sys.eps(2,2)=-1;
sys.eps(1,2)= 1;
sys.eps(2,1)= 1;

%chemical potential for 2 kinds of atoms
sys.mu(1)=0.0;
sys.mu(2)=0.0;

%distance that determines neighbor interaction
sys.rcut=1.0;

%periodic boundarys in latvec1, latvec2, latvec3 (0-> NO, 1->YES)
sys.pbc=[1 1 1];

%make sure system is self consitent
check(sys);
