function [which]=whichCell(supersys,whichatoms)
% WHICHCELL Finds which image cells a group of atoms are in
%   [WHICH]=whichCell(SUPERSYS,whichAtoms) returns a LENGTH(whichAtoms) x 3
%   mattrix which tells which cells whichAtoms are in.  If the cell 
%   is [0 0 0] then the atom is in the home cell.  The first number tells
%   how many cells up/down the atom is based on SUPERSYS.LATVC(:,1).  The
%   next tells how many up/down the atom is based on SUPERSYS.LATVEC(:,2)
%   and similarly for the third lattice vector. An atom in cell [1 0 -1] is
%   in the cell that is one up in the latvec1 direction, in the home cell
%   of latvec2 and one cell down in the latvec3 direction.  
%
%   %Example:
%   >>sys=makesys;
%   >>newsys=makeImageSys(sys);
%   >>whichAtoms=[1 3 5];
%   >>whichFor135=whichCell(newsys,whichAtoms);
%
%   whichFor135 =
%              0  0  0
%              0 -1  0
%              1  0  2
%
% See also MAKEIMAGESYS, FINDNGBRS

%intialize
sys=supersys;
num=length(whichatoms);
pos=sys.pos;
latvec=sys.latvec;
which=[];

%find which cell based on coefficients of latvec\sys.pos'
%Where latvec * coeffs = sys.pos(whichatms,:)
coeffs=(latvec\sys.pos(whichatoms,:)')';

%find which cell each atom in whichatoms is in
which(:,1)=floor(coeffs(:,1));
which(:,2)=floor(coeffs(:,2));
which(:,3)=floor(coeffs(:,3));
